import{cM as n}from"./index.3bb16a7d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="9ca88152-a8e3-4dca-b1b7-8f4a23dd5479",e._sentryDebugIdIdentifier="sentry-dbid-9ca88152-a8e3-4dca-b1b7-8f4a23dd5479")}catch{}})();const t=(e,d,r)=>{n.error({message:e,description:d,onClick:r})};export{t as p};
//# sourceMappingURL=popupNotifcation.a637fa65.js.map
