import{a0 as t,r as s,o as r,c}from"./index.3bb16a7d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="eddfbbc9-582f-4158-b8ae-4eef1fe26e72",e._sentryDebugIdIdentifier="sentry-dbid-eddfbbc9-582f-4158-b8ae-4eef1fe26e72")}catch{}})();const d={};function _(e,o){const n=s("RouterView");return r(),c(n,{class:"router"})}const a=t(d,[["render",_],["__scopeId","data-v-3c2b9654"]]);export{a as default};
//# sourceMappingURL=Home.9bd517b1.js.map
