import"./index.3bb16a7d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="bea654f4-2b4b-43ab-a7dd-19661e9a9ffd",e._sentryDebugIdIdentifier="sentry-dbid-bea654f4-2b4b-43ab-a7dd-19661e9a9ffd")}catch{}})();const f=e=>{try{return new URL(e),!0}catch{return!1}},b=(e,r)=>{if(!Object.keys(r).length)return e;const t=new URL(e),n=new URLSearchParams(t.search);return Object.entries(r).forEach(([a,s])=>{t.searchParams.delete(a),n.set(a,s)}),`${t.origin}${t.pathname}?${n.toString()}`};export{f as i,b as m};
//# sourceMappingURL=url.a49f314c.js.map
