import{O as l}from"./index.3bb16a7d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="4531d067-4211-4843-a12c-37b3b503b087",e._sentryDebugIdIdentifier="sentry-dbid-4531d067-4211-4843-a12c-37b3b503b087")}catch{}})();function d(e){return l.string().email().safeParse(e).success}function f(e){return e.charAt(0).toUpperCase()+e.slice(1)}function g(e,n,r=!1,t=!0,a=!1){const s=(t?e.toLocaleLowerCase():e).normalize("NFD").replace(/[\u0300-\u036f]/g,""),c=a?s.replace(/[^a-zA-Z0-9/]/g,"_"):s.replace(/[^a-zA-Z0-9]/g,"_"),i=r?c:c.replace(/_+/g,"_");return n?i:i.replace(/_$/,"")}function b(e){var o;const r=e.toLocaleLowerCase().trim().normalize("NFD").replace(/[\u0300-\u036f]/g,""),t=/[a-z0-9]+/g,a=r.match(t);return(o=a==null?void 0:a.join("-"))!=null?o:""}export{b as a,f as c,d as i,g as n};
//# sourceMappingURL=string.2eb4b01a.js.map
