import{P as f}from"./PlayerNavbar.6ef55aeb.js";import{d as g,eo as h,ea as c,e as b,f as y,r as k,o as i,Y as v,u as n,c as w,S as L,a as C,b as I,a0 as N}from"./index.3bb16a7d.js";import{u as V}from"./workspaceStore.c875d00a.js";import"./metadata.1411005d.js";import"./PhWebhooksLogo.vue.af4f3a11.js";import"./LoadingOutlined.24477ae4.js";import"./PhSignOut.vue.9522f6f8.js";import"./index.0ee6c454.js";import"./Avatar.30b974d7.js";import"./url.a49f314c.js";import"./colorHelpers.0fdbd497.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="3d5c3cc0-7334-40dd-8a13-72b8d6bb379a",o._sentryDebugIdIdentifier="sentry-dbid-3d5c3cc0-7334-40dd-8a13-72b8d6bb379a")}catch{}})();const x={class:"main-container"},B={class:"content"},D=g({__name:"Main",setup(o){const e=h(),t=V(),d=c().path,a=b(null),u=async({path:s,id:r})=>{a.value=r,await e.push({path:`/${s}`}),a.value=null},l=()=>{e.push({name:"playerLogin"})},p=()=>{e.push({name:"playerLogin"})},_=y(()=>!!c().meta.hideLogin);return(s,r)=>{const m=k("RouterView");return i(),v("div",x,[n(t).state.workspace?(i(),w(f,{key:0,"current-path":n(d),"hide-login":_.value,"runner-data":n(t).state.workspace,loading:a.value,onNavigate:u,onLoginClick:p,onLogoutClick:l},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(m)])])}}});const A=N(D,[["__scopeId","data-v-f095bece"]]);export{A as default};
//# sourceMappingURL=Main.26adbc5f.js.map
