import{_ as m}from"./TasksView.vue_vue_type_script_setup_true_lang.d769e405.js";import{R as f}from"./tasksController.316b9f67.js";import{d as b,ea as _,f as y,o as n,Y as g,b as w,w as k,u as l,c as I,S as T,aS as v,aG as B,dd as S}from"./index.3bb16a7d.js";import"./gateway.b9669ee9.js";import{a as j,B as x}from"./build.3308bb0a.js";import{a as C}from"./project.f64f2c38.js";import"./tables.1a172065.js";import{a as D}from"./asyncComputed.cf9b9270.js";import"./metadata.1411005d.js";import"./PhWebhooksLogo.vue.af4f3a11.js";import"./string.2eb4b01a.js";import"./ant-design.480d4716.js";import"./dayjs.16dbf331.js";import"./index.1cabcd7d.js";import"./polling.e50afa20.js";import"./scripts.3db57a43.js";import"./record.2250875e.js";import"./linters.02dd0e79.js";import"./popupNotifcation.a637fa65.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="53291d3b-da36-41ab-9504-a19ba8889588",e._sentryDebugIdIdentifier="sentry-dbid-53291d3b-da36-41ab-9504-a19ba8889588")}catch{}})();const Q=b({__name:"Tasks",setup(e){const a=_().params.projectId,p=new f(a),{result:o}=D(async()=>{const r=(await j.list(a)).find(c=>c.latest);if(!r)return null;const[u,d]=await Promise.all([x.get(r.id),C.get(a)]);return{buildSpec:u,project:d}}),i=y(()=>!o.value||!o.value.buildSpec?null:o.value.buildSpec.runtimes.map(t=>({id:t.id,stageTitle:t.title,stageType:t.type})));return(t,r)=>(n(),g(v,null,[w(l(S),null,{default:k(()=>[B("Tasks")]),_:1}),i.value?(n(),I(m,{key:0,class:"tasks",api:l(p),stages:i.value},null,8,["api","stages"])):T("",!0)],64))}});export{Q as default};
//# sourceMappingURL=Tasks.e303db19.js.map
