import{C as r,E as t,K as f,a as i,M as c,c as l,P as y,R as g,S as u,b,T as k,U as p,e as w,l as D}from"./toggleHighContrast.3ea05c88.js";import"./index.3bb16a7d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="f2c48564-0fa2-484d-a1d6-67acdf3fffde",e._sentryDebugIdIdentifier="sentry-dbid-f2c48564-0fa2-484d-a1d6-67acdf3fffde")}catch{}})();export{r as CancellationTokenSource,t as Emitter,f as KeyCode,i as KeyMod,c as MarkerSeverity,l as MarkerTag,y as Position,g as Range,u as Selection,b as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.eecd3a0d.js.map
