import{_ as n}from"./TasksView.vue_vue_type_script_setup_true_lang.d769e405.js";import{L as i}from"./tasksController.316b9f67.js";import{d,o as c,c as p,w as a,b as o,aG as _,u as s,dd as f,a0 as m}from"./index.3bb16a7d.js";import{C as l}from"./ContentLayout.5c25c528.js";import"./metadata.1411005d.js";import"./PhWebhooksLogo.vue.af4f3a11.js";import"./string.2eb4b01a.js";import"./ant-design.480d4716.js";import"./dayjs.16dbf331.js";import"./index.1cabcd7d.js";import"./gateway.b9669ee9.js";import"./popupNotifcation.a637fa65.js";import"./polling.e50afa20.js";import"./scripts.3db57a43.js";import"./record.2250875e.js";import"./linters.02dd0e79.js";import"./asyncComputed.cf9b9270.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="d5e6fc9a-add8-408b-9558-6c3bf31066c8",t._sentryDebugIdIdentifier="sentry-dbid-d5e6fc9a-add8-408b-9558-6c3bf31066c8")}catch{}})();const u=d({__name:"Tasks",setup(t){const e=new i;return(r,y)=>(c(),p(l,null,{default:a(()=>[o(s(f),null,{default:a(()=>[_("Tasks")]),_:1}),o(n,{class:"tasks",api:s(e),stages:null,editor:""},null,8,["api"])]),_:1}))}});const G=m(u,[["__scopeId","data-v-10aa4cc9"]]);export{G as default};
//# sourceMappingURL=Tasks.cec13cec.js.map
