import{a0 as n,o,Y as d,$ as s,a,S as c}from"./index.3bb16a7d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="ed8ecd7c-0bdc-4b27-a9fc-e47bca1cfa51",e._sentryDebugIdIdentifier="sentry-dbid-ed8ecd7c-0bdc-4b27-a9fc-e47bca1cfa51")}catch{}})();const r={},f={class:"base-layout"},i={class:"base-middle"},u={key:0,class:"base-footer"};function _(e,t){return o(),d("div",f,[s(e.$slots,"sidebar",{},void 0,!0),a("section",i,[s(e.$slots,"navbar",{},void 0,!0),s(e.$slots,"content",{},void 0,!0),e.$slots.footer?(o(),d("section",u,[s(e.$slots,"footer",{},void 0,!0)])):c("",!0)])])}const y=n(r,[["render",_],["__scopeId","data-v-9ad5be20"]]);export{y as B};
//# sourceMappingURL=BaseLayout.d3e7c403.js.map
