import{d as n,o as d,Y as s,a,$ as r,ed as l,a0 as c}from"./index.3bb16a7d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="d7986023-c1d9-4c38-8de0-9e42614f35ba",e._sentryDebugIdIdentifier="sentry-dbid-d7986023-c1d9-4c38-8de0-9e42614f35ba")}catch{}})();const _={class:"content-layout"},u=n({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,o)=>(d(),s("div",_,[a("div",{class:l(["centered-layout",{"full-width":t.fullWidth}])},[r(t.$slots,"default",{},void 0,!0)],2)]))}});const f=c(u,[["__scopeId","data-v-6397d501"]]);export{f as C};
//# sourceMappingURL=ContentLayout.5c25c528.js.map
