import"./App.vue_vue_type_style_index_0_lang.0bcd9c21.js";import{_ as b}from"./App.vue_vue_type_style_index_0_lang.0bcd9c21.js";import"./workspaceStore.c875d00a.js";import"./index.3bb16a7d.js";import"./url.a49f314c.js";import"./colorHelpers.0fdbd497.js";import"./PlayerConfigProvider.5dfd36db.js";import"./index.a7386f0c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="293c5d54-be46-4fa9-9d3c-3dc00dd895e5",e._sentryDebugIdIdentifier="sentry-dbid-293c5d54-be46-4fa9-9d3c-3dc00dd895e5")}catch{}})();export{b as default};
//# sourceMappingURL=App.6859e665.js.map
