import"./index.3bb16a7d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="9aa92fd5-afe9-4c85-a70d-d3ae38ab3de3",e._sentryDebugIdIdentifier="sentry-dbid-9aa92fd5-afe9-4c85-a70d-d3ae38ab3de3")}catch{}})();const t=(...e)=>window.fetch(...e);export{t as l};
//# sourceMappingURL=fetch.99c44a94.js.map
