import{d as i,eh as l,f as r,o as t,Y as a,S as d,e9 as f,a0 as _}from"./index.3bb16a7d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="262dafc8-630f-4b02-9d93-63cc3faad79b",e._sentryDebugIdIdentifier="sentry-dbid-262dafc8-630f-4b02-9d93-63cc3faad79b")}catch{}})();const p={class:"logo"},u=["src","alt"],g={key:1},b=i({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){const s=e;l(o=>({bb5bcf84:n.value}));const n=r(()=>s.size==="small"?"24px":s.size==="large"?"80px":"50px"),c=r(()=>`${s.brandName} Logo`);return(o,m)=>(t(),a("div",p,[o.imageUrl?(t(),a("img",{key:0,class:"logo-img",src:o.imageUrl,alt:c.value},null,8,u)):d("",!0),o.hideText?d("",!0):(t(),a("span",g,f(o.brandName),1))]))}});const h=_(b,[["__scopeId","data-v-8d11f0bb"]]);export{h as L};
//# sourceMappingURL=Logo.913dce72.js.map
