import{d as i,o as p,c as n,w as a,b as m,u as r}from"./index.3bb16a7d.js";import"./linters.02dd0e79.js";import{W as s}from"./workspaces.d7ea87a4.js";import{C as d}from"./ContentLayout.5c25c528.js";import{_ as f,E as c}from"./View.vue_vue_type_script_setup_true_lang.be63e722.js";import"./asyncComputed.cf9b9270.js";import"./workspaceStore.c875d00a.js";import"./url.a49f314c.js";import"./colorHelpers.0fdbd497.js";import"./record.2250875e.js";import"./gateway.b9669ee9.js";import"./popupNotifcation.a637fa65.js";import"./fetch.99c44a94.js";import"./SaveButton.d566e6d5.js";import"./UnsavedChangesHandler.50a445b7.js";import"./ExclamationCircleOutlined.b6d84f94.js";import"./CrudView.b50d64df.js";import"./router.61d8b367.js";import"./Badge.a2ade0a9.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.81487614.js";import"./BookOutlined.435ccdd9.js";import"./PhDotsThreeVertical.vue.7ef3061b.js";import"./index.1cabcd7d.js";import"./index.d713b8dc.js";import"./polling.e50afa20.js";import"./PhPencil.vue.88a66847.js";import"./index.2827b1cb.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="e02c3be9-763e-4e30-a0ba-a35819d7ea4b",o._sentryDebugIdIdentifier="sentry-dbid-e02c3be9-763e-4e30-a0ba-a35819d7ea4b")}catch{}})();const G=i({__name:"EnvVarsEditor",setup(o){const e=new c;return(t,u)=>(p(),n(d,null,{default:a(()=>[m(f,{"env-var-repository":r(e),mode:"editor","file-opener":r(s)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{G as default};
//# sourceMappingURL=EnvVarsEditor.945ac54a.js.map
