import{k as i,T as n,m as r,P as o,C as p,M as c,s as d,n as s,p as m,q as u,t as f,v as g}from"./index.3bb16a7d.js";import{s as y,c as l,a}from"./workspaceStore.c875d00a.js";import{_ as b}from"./App.vue_vue_type_style_index_0_lang.0bcd9c21.js";import"./url.a49f314c.js";import"./colorHelpers.0fdbd497.js";import"./PlayerConfigProvider.5dfd36db.js";import"./index.a7386f0c.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="71a81438-1234-4c23-ba5a-71ce03ee5e42",t._sentryDebugIdIdentifier="sentry-dbid-71a81438-1234-4c23-ba5a-71ce03ee5e42")}catch{}})();class w{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await y();const t=l(),e=i({render:()=>m(b)});n.init(),r(e,a),w.init(),e.use(a),e.use(t),e.use(o),e.mount("#app"),e.component("VSelect",p),e.component("Markdown",c),e.component("Message",d),s(e,u),s(e,f),s(e,g)})();
//# sourceMappingURL=player.82f24625.js.map
