import{O as r}from"./workspaceStore.c875d00a.js";import{d as l,X as i,o as u,Y as c,b as a,w as d,u as o,aG as n,dd as f,dc as _}from"./index.3bb16a7d.js";import"./url.a49f314c.js";import"./colorHelpers.0fdbd497.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="dd6d30ee-4caa-498d-9f50-bcd796857e5e",e._sentryDebugIdIdentifier="sentry-dbid-dd6d30ee-4caa-498d-9f50-bcd796857e5e")}catch{}})();const w=l({__name:"OidcLogoutCallback",setup(e){return i(async()=>{await new r().logoutCallback()}),(t,s)=>(u(),c("div",null,[a(o(f),null,{default:d(()=>[n("You're authenticated")]),_:1}),a(o(_),null,{default:d(()=>[n(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLogoutCallback.16f0e5de.js.map
