import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.be63e722.js";import{d as i,ea as s,o as m,c as a,u as c}from"./index.3bb16a7d.js";import"./gateway.b9669ee9.js";import"./popupNotifcation.a637fa65.js";import"./fetch.99c44a94.js";import"./record.2250875e.js";import"./SaveButton.d566e6d5.js";import"./UnsavedChangesHandler.50a445b7.js";import"./ExclamationCircleOutlined.b6d84f94.js";import"./CrudView.b50d64df.js";import"./router.61d8b367.js";import"./Badge.a2ade0a9.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.81487614.js";import"./BookOutlined.435ccdd9.js";import"./url.a49f314c.js";import"./PhDotsThreeVertical.vue.7ef3061b.js";import"./index.1cabcd7d.js";import"./index.d713b8dc.js";import"./asyncComputed.cf9b9270.js";import"./polling.e50afa20.js";import"./PhPencil.vue.88a66847.js";import"./index.2827b1cb.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="446f252e-6cb3-472c-93df-7cf25a99bd29",o._sentryDebugIdIdentifier="sentry-dbid-446f252e-6cb3-472c-93df-7cf25a99bd29")}catch{}})();const A=i({__name:"EnvVars",setup(o){const t=s().params.projectId,e=new p(t);return(d,f)=>(m(),a(n,{"env-var-repository":c(e),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars.1a464ca3.js.map
